![alt text](cowbat.png "Cowbat")

### CFIA OLC Workflow for Bacterial Assembly and Typing

#### [Read the Docs](http://olc-bioinformatics.github.io/COWBAT/)

[![Build Status](https://travis-ci.org/OLC-Bioinformatics/COWBAT.svg?branch=master)](https://travis-ci.org/OLC-Bioinformatics/COWBAT)
